==> haskell-mustache-2.3.0-214-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mustache
version: 2.3.0
id: mustache-2.3.0-89t4vTizbEC3FjpOhbjbKu
key: mustache-2.3.0-89t4vTizbEC3FjpOhbjbKu
license: BSD-3-Clause
copyright: (c) 2015,
           2016 Justus Adam
maintainer: dev@justus.science
author: Justus Adam
homepage: https://github.com/JustusAdam/mustache
synopsis: A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.
    .
    Implements the mustache spec version 1.1.3.
    .
    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.
category: Development
abi: df452042c16282e9a2b1d49f7615c5bc
exposed: True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types
hidden-modules: Text.Mustache.Internal Text.Mustache.Internal.Types
                Paths_mustache
import-dirs: /usr/lib/ghc-8.6.5/site-local/mustache-2.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/mustache-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mustache-2.3.0
hs-libraries: HSmustache-2.3.0-89t4vTizbEC3FjpOhbjbKu
depends:
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    either-5.0.1.1-7hr5RhXy4Gs2hmqdZxPR9U filepath-1.4.2.1 mtl-2.2.2
    parsec-3.1.13.0 scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.7.11-hZJVZ2zmXw59mRAYP9RXW
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html: /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mustache-2.3.0-216-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mustache
version: 2.3.0
id: mustache-2.3.0-A6Mh19Sp4tCGVGFAApZF0v
key: mustache-2.3.0-A6Mh19Sp4tCGVGFAApZF0v
license: BSD-3-Clause
copyright: (c) 2015,
           2016 Justus Adam
maintainer: dev@justus.science
author: Justus Adam
homepage: https://github.com/JustusAdam/mustache
synopsis: A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.
    .
    Implements the mustache spec version 1.1.3.
    .
    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.
category: Development
abi: 0902ee9cdcf3ee54b881e46f7136fa77
exposed: True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types
hidden-modules: Text.Mustache.Internal Text.Mustache.Internal.Types
                Paths_mustache
import-dirs: /usr/lib/ghc-8.6.5/site-local/mustache-2.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/mustache-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mustache-2.3.0
hs-libraries: HSmustache-2.3.0-A6Mh19Sp4tCGVGFAApZF0v
depends:
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    either-5.0.1.1-HaqyuduLEaxGv5ycSZlkOT filepath-1.4.2.1 mtl-2.2.2
    parsec-3.1.13.0 scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.7.11-hZJVZ2zmXw59mRAYP9RXW
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html: /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
